<?php
/**
 * Extension name: Call External API
 * Descrption: Using this extension we will call an external API
 * Author: EE 
 * 
 */

namespace Opencart\Admin\Controller\Extension\CallExternalApi\Module;

class CallExternalApi extends \Opencart\System\Engine\Controller {
    public function index(): void {
        /$this->load->language('extension/callExternalApi/module/callExternalApi');

		$this->document->setTitle($this->language->get('heading_title'));

		$data['breadcrumbs'] = [];
		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'])
		];
		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module')
		];
		$data['breadcrumbs'][] = [
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('extension/callExternalApi/module/callExternalApi', 'user_token=' . $this->session->data['user_token'])
		];

		$data['save'] = $this->url->link('extension/callExternalApi/module/callExternalApi'.$this->method_separator.'save', 'user_token=' . $this->session->data['user_token']);
		$data['back'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module');

		$data['module_callExternalApi_status'] = $this->config->get('module_callExternalApi_status');

		$data['success'] = '';
		if (!empty($this->session->data['module_callExternalApi_success'])) {
			$data['success'] = $this->session->data['module_callExternalApi_success'];
			unset($this->session->data['module_callExternalApi_success']);
		}

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/callExternalApi/module/callExternalApi', $data));
    }




    public function save(): void {
        $this->load->language('extension/callExternalApi/module/callExternalApi');

        $json = [];

        if (!$this->user->hasPermission('modify', 'extension/callExternalApi/module/callExternalApi')) {
            $json['error'] = $this->language->get('error_permission');
        }

        if (!$json) {
            $this->load->model('setting/setting');

            $this->model_setting_setting->editSetting('moduel_callExternalApi', $this->request->post);

            $json['redirect'] = str_replace('&amp;','&',$this->url->link('extension/callExternalApi/module/callExternalApi', 'user_token=' . $this->session->data['user_token']));
            $this->session->data['moduel_callExternalApi'] = $this->language->get('text_success');
        }

        $this->response->addHeader('Content-Type: application/json');
        $this->response->setOutput(json_encode($json));
    }

    public function install(): void {
        // add events
        $this->load->model('setting/event');
        $data = [
            'code'        => 'module_callExternalApi',
            'description' => '',
            'trigger'     => 'catalog/model/checkout/order/addOrder/after',
            'action'      => 'extension/callExternalApi/module/callExternalApi',
            'status'      => true,
            'sort_order'  => 0
        ];
        $this->model_setting_event->addEvent($data);

        // add access rights
        $this->addAccessRights();
    }


    public function uninstall(): void {
        // remove events
        $this->load->model('setting/event');
        $this->model_setting_event->deleteEventByCode('module_callExternalApi');

        // remove access rights
        $this->removeAccessRights();
    }

        // Make API call using cURL



/*         $curl = curl_init($api_url);
        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($data));
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        $response = curl_exec($curl);
        curl_close($curl); */



        // Process API response if needed
        
/*         if ($response === false) {
            // API call failed, handle the error
        } else {
            // API call successful, process the response
        } */
}
?>